diff --git a/applications/solvers/DNS/dnsFoam/Make/options b/applications/solvers/DNS/dnsFoam/Make/options
index 34c3503a51737b0cbe058747a1b9a55fc0ed0282..e0e7a30d72df5ee6b9f4fdc6b4c44aa8724edb50 100644
--- a/applications/solvers/DNS/dnsFoam/Make/options
+++ b/applications/solvers/DNS/dnsFoam/Make/options
@@ -1,10 +1,7 @@
 EXE_INC = \
     -I$(LIB_SRC)/finiteVolume/lnInclude \
-    -I$(LIB_SRC)/randomProcesses/lnInclude \
-    -I$(LIB_SRC)/sampling/lnInclude
+    -I$(LIB_SRC)/randomProcesses/lnInclude
 
 EXE_LIBS = \
     -lfiniteVolume \
-    -lrandomProcesses \
-    -lsampling \
-    -lmeshTools
+    -lrandomProcesses
diff --git a/applications/solvers/combustion/PDRFoam/Make/options b/applications/solvers/combustion/PDRFoam/Make/options
index 135659c2766cb7ec98124f7969e95a8fad1d6f48..b6c6398fdea5b27262b932e70ebb32a5cf5dc078 100644
--- a/applications/solvers/combustion/PDRFoam/Make/options
+++ b/applications/solvers/combustion/PDRFoam/Make/options
@@ -5,7 +5,6 @@ EXE_INC = \
     -IPDRModels/dragModels/PDRDragModel \
     -IlaminarFlameSpeed/SCOPE \
     -I$(LIB_SRC)/engine/lnInclude \
-    -I$(LIB_SRC)/sampling/lnInclude \
     -I$(LIB_SRC)/thermophysicalModels/specie/lnInclude \
     -I$(LIB_SRC)/thermophysicalModels/basic/lnInclude \
     -I$(LIB_SRC)/thermophysicalModels/reactionThermo/lnInclude \
diff --git a/applications/solvers/combustion/XiFoam/Make/options b/applications/solvers/combustion/XiFoam/Make/options
index 0812df5e3bf3bb3979d1bde18c97acb35b91583d..3a07a7de587f6b8951465bc598356c4e5a5cb0d3 100644
--- a/applications/solvers/combustion/XiFoam/Make/options
+++ b/applications/solvers/combustion/XiFoam/Make/options
@@ -5,7 +5,7 @@ EXE_INC = \
     -I$(LIB_SRC)/thermophysicalModels/reactionThermo/lnInclude \
     -I$(LIB_SRC)/turbulenceModels/compressible/turbulenceModel \
     -I$(LIB_SRC)/thermophysicalModels/laminarFlameSpeed/lnInclude \
-    -I$(LIB_SRC)/sampling/lnInclude \
+    -I$(LIB_SRC)/meshTools/lnInclude \
     -I$(LIB_SRC)/finiteVolume/lnInclude
 
 EXE_LIBS = \
@@ -17,5 +17,5 @@ EXE_LIBS = \
     -lreactionThermophysicalModels \
     -lspecie \
     -llaminarFlameSpeedModels \
-    -lfiniteVolume \
-    -lmeshTools
+    -lmeshTools \
+    -lfiniteVolume
diff --git a/applications/solvers/combustion/coldEngineFoam/Make/options b/applications/solvers/combustion/coldEngineFoam/Make/options
index 25217ab23f79c72d9f81c2aba8eb51c0ae138c30..2eaea744b0c5e93ec6a199f72e5463679da2333d 100644
--- a/applications/solvers/combustion/coldEngineFoam/Make/options
+++ b/applications/solvers/combustion/coldEngineFoam/Make/options
@@ -20,6 +20,5 @@ EXE_LIBS = \
     -lfluidThermophysicalModels \
     -lspecie \
     -lfiniteVolume \
-    -lsampling \
     -lmeshTools \
     -lfieldSources
diff --git a/applications/solvers/incompressible/icoFoam/Make/options b/applications/solvers/incompressible/icoFoam/Make/options
index fa15f124528ebfcaf279a88a73a0d7954f2e9dc1..d38cd8b1801b429e5f42c7b0ba2ab58ba2cd1d11 100644
--- a/applications/solvers/incompressible/icoFoam/Make/options
+++ b/applications/solvers/incompressible/icoFoam/Make/options
@@ -1,5 +1,7 @@
 EXE_INC = \
-    -I$(LIB_SRC)/finiteVolume/lnInclude
+    -I$(LIB_SRC)/finiteVolume/lnInclude \
+    -I$(LIB_SRC)/sampling/lnInclude
 
 EXE_LIBS = \
-    -lfiniteVolume
+    -lfiniteVolume \
+    -lsampling
diff --git a/applications/utilities/mesh/generation/cvMesh/Make/options b/applications/utilities/mesh/generation/cvMesh/Make/options
index 2228fc2b121966cd0063aa3a5afeadd2f4a31202..27241b29656f8f37f263f53f2697d4b8251cabda 100644
--- a/applications/utilities/mesh/generation/cvMesh/Make/options
+++ b/applications/utilities/mesh/generation/cvMesh/Make/options
@@ -17,7 +17,7 @@ EXE_INC = \
     -I$(LIB_SRC)/meshTools/lnInclude \
     -I$(LIB_SRC)/parallel/decompose/decompositionMethods/lnInclude \
     -I$(LIB_SRC)/edgeMesh/lnInclude \
-    -I$(LIB_SRC)/sampling/lnInclude \
+    -I$(LIB_SRC)/fileFormats/lnInclude \
     -I$(LIB_SRC)/dynamicMesh/lnInclude \
     -I$(LIB_SRC)/triSurface/lnInclude
 
@@ -30,6 +30,6 @@ EXE_LIBS = \
     -ldecompositionMethods \
     -L$(FOAM_LIBBIN)/dummy -lptscotchDecomp \
     -ledgeMesh \
-    -lsampling \
+    -lfileFormats \
     -ltriSurface \
     -ldynamicMesh
diff --git a/applications/utilities/mesh/generation/cvMesh/conformalVoronoiMesh/Make/options b/applications/utilities/mesh/generation/cvMesh/conformalVoronoiMesh/Make/options
index 62649cf23282eb467b02bbc51b116c928b76e4c8..2082f88ff045c1cff3ff1238ebcba1a4a0af978d 100644
--- a/applications/utilities/mesh/generation/cvMesh/conformalVoronoiMesh/Make/options
+++ b/applications/utilities/mesh/generation/cvMesh/conformalVoronoiMesh/Make/options
@@ -17,7 +17,7 @@ EXE_INC = \
     -I$(LIB_SRC)/meshTools/lnInclude \
     -I$(LIB_SRC)/parallel/decompose/decompositionMethods/lnInclude \
     -I$(LIB_SRC)/edgeMesh/lnInclude \
-    -I$(LIB_SRC)/sampling/lnInclude \
+    -I$(LIB_SRC)/fileFormats/lnInclude \
     -I$(LIB_SRC)/dynamicMesh/lnInclude \
     -I$(LIB_SRC)/triSurface/lnInclude \
     -I../vectorTools
@@ -25,5 +25,6 @@ EXE_INC = \
 EXE_LIBS = \
     -lmeshTools \
     -ledgeMesh \
+    -lfileFormats \
     -ltriSurface \
     -ldynamicMesh
diff --git a/applications/utilities/mesh/generation/cvMesh/cvMeshBackgroundMesh/Make/options b/applications/utilities/mesh/generation/cvMesh/cvMeshBackgroundMesh/Make/options
index 2d1ad7bfdae88ad8cc5e9c295859aacad27d7198..ed71a800294b791b6968359c38a257306d79da23 100644
--- a/applications/utilities/mesh/generation/cvMesh/cvMeshBackgroundMesh/Make/options
+++ b/applications/utilities/mesh/generation/cvMesh/cvMeshBackgroundMesh/Make/options
@@ -11,10 +11,11 @@ EXE_INC = \
     -I../conformalVoronoiMesh/lnInclude \
     -I$(LIB_SRC)/parallel/decompose/decompositionMethods/lnInclude \
     -I$(LIB_SRC)/edgeMesh/lnInclude \
-    -I$(LIB_SRC)/sampling/lnInclude \
     -I$(LIB_SRC)/triSurface/lnInclude \
     -I$(LIB_SRC)/finiteVolume/lnInclude \
     -I$(LIB_SRC)/meshTools/lnInclude \
+    -I$(LIB_SRC)/fileFormats/lnInclude \
+    -I$(LIB_SRC)/sampling/lnInclude \
     -I$(LIB_SRC)/dynamicMesh/lnInclude
 
 EXE_LIBS = \
@@ -24,8 +25,9 @@ EXE_LIBS = \
     -lconformalVoronoiMesh \
     -ldecompositionMethods /* -L$(FOAM_LIBBIN)/dummy -lscotchDecomp */ \
     -ledgeMesh \
-    -lsampling \
     -ltriSurface \
     -lmeshTools \
+    -lfileFormats \
+    -lsampling \
     -ldynamicMesh \
     -lfiniteVolume
diff --git a/applications/utilities/mesh/generation/cvMesh/cvMeshSurfaceSimplify/Make/options b/applications/utilities/mesh/generation/cvMesh/cvMeshSurfaceSimplify/Make/options
index 35c90b1f48a814892bce172cb3a1a4d31152b163..7bd92a24abf566234ee02a26c3615c10151286a1 100644
--- a/applications/utilities/mesh/generation/cvMesh/cvMeshSurfaceSimplify/Make/options
+++ b/applications/utilities/mesh/generation/cvMesh/cvMeshSurfaceSimplify/Make/options
@@ -9,7 +9,7 @@ EXE_INC = \
     -I$(FASTDUALOCTREE_SRC_PATH) \
     -I../conformalVoronoiMesh/lnInclude \
     -I$(LIB_SRC)/edgeMesh/lnInclude \
-    -I$(LIB_SRC)/sampling/lnInclude \
+    -I$(LIB_SRC)/fileFormats/lnInclude \
     -I$(LIB_SRC)/triSurface/lnInclude \
     -I$(LIB_SRC)/meshTools/lnInclude
 
@@ -22,7 +22,7 @@ EXE_LIBS = \
     -lconformalVoronoiMesh \
     -ldecompositionMethods -L$(FOAM_LIBBIN)/dummy -lscotchDecomp \
     -ledgeMesh \
-    -lsampling \
+    -lfileFormats \
     -ltriSurface \
     -lmeshTools \
     -ldynamicMesh
diff --git a/applications/utilities/mesh/generation/snappyHexMesh/Make/options b/applications/utilities/mesh/generation/snappyHexMesh/Make/options
index 94ff17ee9979e9c63d98f3513d7d24a564277430..af056ec7cb640728dde3af9003c460d860c4bbb7 100644
--- a/applications/utilities/mesh/generation/snappyHexMesh/Make/options
+++ b/applications/utilities/mesh/generation/snappyHexMesh/Make/options
@@ -3,7 +3,7 @@ EXE_INC = \
     -I$(LIB_SRC)/parallel/decompose/decompositionMethods/lnInclude \
     -I$(LIB_SRC)/mesh/autoMesh/lnInclude \
     -I$(LIB_SRC)/meshTools/lnInclude \
-    -I$(LIB_SRC)/sampling/lnInclude \
+    -I$(LIB_SRC)/fileFormats/lnInclude \
     -I$(LIB_SRC)/triSurface/lnInclude \
     -I$(LIB_SRC)/dynamicMesh/lnInclude \
     -I$(LIB_SRC)/edgeMesh/lnInclude \
@@ -14,6 +14,6 @@ EXE_LIBS = \
     -ldecompositionMethods \
     -L$(FOAM_LIBBIN)/dummy -lptscotchDecomp \
     -lmeshTools \
-    -lsampling \
+    -lfileFormats \
     -ldynamicMesh \
     -lautoMesh
diff --git a/applications/utilities/postProcessing/dataConversion/foamToGMV/Make/options b/applications/utilities/postProcessing/dataConversion/foamToGMV/Make/options
index 5c515d8f95b74b2155dc0d75f0fda4bc389a7130..87b432481021cc47b9d9dcbbbfc4be342bd1ac53 100644
--- a/applications/utilities/postProcessing/dataConversion/foamToGMV/Make/options
+++ b/applications/utilities/postProcessing/dataConversion/foamToGMV/Make/options
@@ -1,15 +1,9 @@
 EXE_INC = \
     -I$(LIB_SRC)/finiteVolume/lnInclude \
-    -I$(LIB_SRC)/sampling/lnInclude \
     -I$(LIB_SRC)/meshTools/lnInclude \
-    -I$(LIB_SRC)/turbulenceModels/incompressible/lnInclude \
     -I$(LIB_SRC)/transportModels/incompressible/lnInclude \
-    -I$(LIB_SRC)/lagrangian/lnInclude \
-    -I$(LIB_SRC)/thermophysicalModels/liquids/lnInclude \
     -I$(LIB_SRC)/thermophysicalModels/specie/lnInclude \
     -I$(LIB_SRC)/thermophysicalModels/thermophysicalFunctions/lnInclude \
-    -I$(LIB_SRC)/browser/lnInclude \
-    -I$(LIB_SRC)/foam/lnInclude \
     -I$(LIB_SRC)/lagrangian/basic/lnInclude
 
 EXE_LIBS = \
diff --git a/applications/utilities/postProcessing/lagrangian/particleTracks/Make/options b/applications/utilities/postProcessing/lagrangian/particleTracks/Make/options
index 3bcea78b3b21c4981a3fc3b20014411934fbb380..b653926f93a610c3f724d7b7a4e3855f9492d145 100644
--- a/applications/utilities/postProcessing/lagrangian/particleTracks/Make/options
+++ b/applications/utilities/postProcessing/lagrangian/particleTracks/Make/options
@@ -1,12 +1,12 @@
 EXE_INC = \
     -I$(LIB_SRC)/finiteVolume/lnInclude \
     -I$(LIB_SRC)/meshTools/lnInclude \
-    -I$(LIB_SRC)/sampling/lnInclude \
+    -I$(LIB_SRC)/fileFormats/lnInclude \
     -I$(LIB_SRC)/lagrangian/basic/lnInclude
 
 EXE_LIBS = \
     -lfiniteVolume \
     -lmeshTools \
-    -lsampling \
+    -lfileFormats \
     -lgenericPatchFields \
     -llagrangian
diff --git a/applications/utilities/postProcessing/sampling/sample/Make/options b/applications/utilities/postProcessing/sampling/sample/Make/options
index 88c6039b4e048acf84a463e29ff47746419c9d85..4de726a20fe6d4836f6aa33f3576202aec07fcdc 100644
--- a/applications/utilities/postProcessing/sampling/sample/Make/options
+++ b/applications/utilities/postProcessing/sampling/sample/Make/options
@@ -1,6 +1,7 @@
 EXE_INC = \
     -I$(LIB_SRC)/finiteVolume/lnInclude \
     -I$(LIB_SRC)/meshTools/lnInclude \
+    -I$(LIB_SRC)/fileFormats/lnInclude \
     -I$(LIB_SRC)/sampling/lnInclude \
     -I$(LIB_SRC)/surfMesh/lnInclude \
     -I$(LIB_SRC)/lagrangian/basic/lnInclude
@@ -9,6 +10,7 @@ EXE_LIBS = \
     -lfiniteVolume \
     -lgenericPatchFields \
     -lmeshTools \
+    -lfileFormats \
     -lsampling \
     -lsurfMesh \
     -llagrangian
diff --git a/applications/utilities/postProcessing/velocityField/Pe/Make/options b/applications/utilities/postProcessing/velocityField/Pe/Make/options
index 29d9b4d8c303aacfa11a0947d384d103d21923e4..1d984aa9b559049112c465682139fcf44dcd7daf 100644
--- a/applications/utilities/postProcessing/velocityField/Pe/Make/options
+++ b/applications/utilities/postProcessing/velocityField/Pe/Make/options
@@ -5,8 +5,7 @@ EXE_INC = \
     -I$(LIB_SRC)/turbulenceModels/LES/LESdeltas/lnInclude \
     -I$(LIB_SRC)/thermophysicalModels/basic/lnInclude \
     -I$(LIB_SRC)/finiteVolume/lnInclude \
-    -I$(LIB_SRC)/meshTools/lnInclude \
-    -I$(LIB_SRC)/sampling/lnInclude
+    -I$(LIB_SRC)/meshTools/lnInclude
 
 EXE_LIBS = \
     $(FOAM_LIBBIN)/postCalc.o \
diff --git a/applications/utilities/preProcessing/boxTurb/Make/options b/applications/utilities/preProcessing/boxTurb/Make/options
index 749a3d512477c50731fad604faf65992b488f76e..e24cee9cb9d235b1870e28189a8633d7352dbe7c 100644
--- a/applications/utilities/preProcessing/boxTurb/Make/options
+++ b/applications/utilities/preProcessing/boxTurb/Make/options
@@ -1,10 +1,7 @@
 EXE_INC = \
     -I$(LIB_SRC)/randomProcesses/lnInclude \
-    -I$(LIB_SRC)/finiteVolume/lnInclude \
-    -I$(LIB_SRC)/sampling/lnInclude
+    -I$(LIB_SRC)/finiteVolume/lnInclude
 
 EXE_LIBS = \
     -lrandomProcesses \
-    -lsampling \
-    -lmeshTools \
     -lfiniteVolume
diff --git a/src/OpenFOAM/db/Time/Time.C b/src/OpenFOAM/db/Time/Time.C
index 155c4c2eb48456ef366aa43b7de061321f16dca6..8619e2da91669622d1a06bba18bdc9415368e234 100644
--- a/src/OpenFOAM/db/Time/Time.C
+++ b/src/OpenFOAM/db/Time/Time.C
@@ -324,6 +324,7 @@ Foam::Time::Time
     secondaryWriteControl_(wcTimeStep),
     secondaryWriteInterval_(labelMax/10.0), // bit less to allow calculations
     purgeWrite_(0),
+    secondaryPurgeWrite_(0),
     writeOnce_(false),
     subCycling_(false),
     sigWriteNow_(true, *this),
@@ -416,6 +417,7 @@ Foam::Time::Time
     secondaryWriteControl_(wcTimeStep),
     secondaryWriteInterval_(labelMax/10.0),
     purgeWrite_(0),
+    secondaryPurgeWrite_(0),
     writeOnce_(false),
     subCycling_(false),
     sigWriteNow_(true, *this),
@@ -511,6 +513,7 @@ Foam::Time::Time
     secondaryWriteControl_(wcTimeStep),
     secondaryWriteInterval_(labelMax/10.0),
     purgeWrite_(0),
+    secondaryPurgeWrite_(0),
     writeOnce_(false),
     subCycling_(false),
     sigWriteNow_(true, *this),
@@ -608,6 +611,7 @@ Foam::Time::Time
     secondaryWriteControl_(wcTimeStep),
     secondaryWriteInterval_(labelMax/10.0),
     purgeWrite_(0),
+    secondaryPurgeWrite_(0),
     writeOnce_(false),
     subCycling_(false),
 
@@ -1070,11 +1074,13 @@ Foam::Time& Foam::Time::operator++()
 
 
         outputTime_ = false;
+        primaryOutputTime_ = false;
+        secondaryOutputTime_ = false;
 
         switch (writeControl_)
         {
             case wcTimeStep:
-                outputTime_ = !(timeIndex_ % label(writeInterval_));
+                primaryOutputTime_ = !(timeIndex_ % label(writeInterval_));
             break;
 
             case wcRunTime:
@@ -1088,7 +1094,7 @@ Foam::Time& Foam::Time::operator++()
 
                 if (outputIndex > outputTimeIndex_)
                 {
-                    outputTime_ = true;
+                    primaryOutputTime_ = true;
                     outputTimeIndex_ = outputIndex;
                 }
             }
@@ -1103,7 +1109,7 @@ Foam::Time& Foam::Time::operator++()
                 );
                 if (outputIndex > outputTimeIndex_)
                 {
-                    outputTime_ = true;
+                    primaryOutputTime_ = true;
                     outputTimeIndex_ = outputIndex;
                 }
             }
@@ -1118,7 +1124,7 @@ Foam::Time& Foam::Time::operator++()
                 );
                 if (outputIndex > outputTimeIndex_)
                 {
-                    outputTime_ = true;
+                    primaryOutputTime_ = true;
                     outputTimeIndex_ = outputIndex;
                 }
             }
@@ -1130,9 +1136,8 @@ Foam::Time& Foam::Time::operator++()
         switch (secondaryWriteControl_)
         {
             case wcTimeStep:
-                outputTime_ =
-                    outputTime_
-                || !(timeIndex_ % label(secondaryWriteInterval_));
+                secondaryOutputTime_ =
+                    !(timeIndex_ % label(secondaryWriteInterval_));
             break;
 
             case wcRunTime:
@@ -1146,7 +1151,7 @@ Foam::Time& Foam::Time::operator++()
 
                 if (outputIndex > secondaryOutputTimeIndex_)
                 {
-                    outputTime_ = true;
+                    secondaryOutputTime_ = true;
                     secondaryOutputTimeIndex_ = outputIndex;
                 }
             }
@@ -1161,7 +1166,7 @@ Foam::Time& Foam::Time::operator++()
                 );
                 if (outputIndex > secondaryOutputTimeIndex_)
                 {
-                    outputTime_ = true;
+                    secondaryOutputTime_ = true;
                     secondaryOutputTimeIndex_ = outputIndex;
                 }
             }
@@ -1176,7 +1181,7 @@ Foam::Time& Foam::Time::operator++()
                 );
                 if (outputIndex > secondaryOutputTimeIndex_)
                 {
-                    outputTime_ = true;
+                    secondaryOutputTime_ = true;
                     secondaryOutputTimeIndex_ = outputIndex;
                 }
             }
@@ -1184,6 +1189,9 @@ Foam::Time& Foam::Time::operator++()
         }
 
 
+        outputTime_ = primaryOutputTime_ || secondaryOutputTime_;
+
+
         // see if endTime needs adjustment to stop at the next run()/end() check
         if (!end())
         {
@@ -1195,6 +1203,7 @@ Foam::Time& Foam::Time::operator++()
             {
                 endTime_ = value();
                 outputTime_ = true;
+                primaryOutputTime_ = true;
             }
             else if (stopAt_ == saNextWrite && outputTime_ == true)
             {
@@ -1205,6 +1214,7 @@ Foam::Time& Foam::Time::operator++()
         // Override outputTime if one-shot writing
         if (writeOnce_)
         {
+            primaryOutputTime_ = true;
             outputTime_ = true;
             writeOnce_ = false;
         }
diff --git a/src/OpenFOAM/db/Time/Time.H b/src/OpenFOAM/db/Time/Time.H
index 26e6b21bc7bbeef91186169940c056d17dc68153..1e761cd73eaaff3d81b4a27d15c996d885bbd19c 100644
--- a/src/OpenFOAM/db/Time/Time.H
+++ b/src/OpenFOAM/db/Time/Time.H
@@ -2,7 +2,7 @@
   =========                 |
   \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
    \\    /   O peration     |
-    \\  /    A nd           | Copyright (C) 2011 OpenFOAM Foundation
+    \\  /    A nd           | Copyright (C) 2011-2012 OpenFOAM Foundation
      \\/     M anipulation  |
 -------------------------------------------------------------------------------
 License
@@ -138,10 +138,15 @@ protected:
 
             scalar secondaryWriteInterval_;
 
-
         label  purgeWrite_;
         mutable FIFOStack<word> previousOutputTimes_;
 
+        // Additional purging
+
+            label  secondaryPurgeWrite_;
+            mutable FIFOStack<word> previousSecondaryOutputTimes_;
+
+
         // One-shot writing
         bool writeOnce_;
 
diff --git a/src/OpenFOAM/db/Time/TimeIO.C b/src/OpenFOAM/db/Time/TimeIO.C
index 6a80618404ef323e9b9a2d1cfa79fed6fd1e75ae..1637d35bfcfe598fc4effec0f94f9b9798550059 100644
--- a/src/OpenFOAM/db/Time/TimeIO.C
+++ b/src/OpenFOAM/db/Time/TimeIO.C
@@ -160,6 +160,20 @@ void Foam::Time::readDict()
         }
     }
 
+    if (controlDict_.readIfPresent("secondaryPurgeWrite", secondaryPurgeWrite_))
+    {
+        if (secondaryPurgeWrite_ < 0)
+        {
+            WarningIn("Time::readDict()")
+                << "invalid value for secondaryPurgeWrite "
+                << secondaryPurgeWrite_
+                << ", should be >= 0, setting to 0"
+                << endl;
+
+            secondaryPurgeWrite_ = 0;
+        }
+    }
+
     if (controlDict_.found("timeFormat"))
     {
         const word formatName(controlDict_.lookup("timeFormat"));
@@ -347,13 +361,45 @@ bool Foam::Time::writeObject
         timeDict.regIOobject::writeObject(fmt, ver, cmp);
         bool writeOK = objectRegistry::writeObject(fmt, ver, cmp);
 
-        if (writeOK && purgeWrite_)
+        if (writeOK)
         {
-            previousOutputTimes_.push(tmName);
+            // Does primary or secondary time trigger purging?
+            // Note that primary times can only be purged by primary
+            // purging. Secondary times can be purged by either primary
+            // or secondary purging.
+            if (primaryOutputTime_ && purgeWrite_)
+            {
+                previousOutputTimes_.push(tmName);
 
-            while (previousOutputTimes_.size() > purgeWrite_)
+                while (previousOutputTimes_.size() > purgeWrite_)
+                {
+                    rmDir(objectRegistry::path(previousOutputTimes_.pop()));
+                }
+            }
+            if
+            (
+               !primaryOutputTime_
+             && secondaryOutputTime_
+             && secondaryPurgeWrite_
+            )
             {
-                rmDir(objectRegistry::path(previousOutputTimes_.pop()));
+                // Writing due to secondary
+                previousSecondaryOutputTimes_.push(tmName);
+
+                while
+                (
+                    previousSecondaryOutputTimes_.size()
+                  > secondaryPurgeWrite_
+                )
+                {
+                    rmDir
+                    (
+                        objectRegistry::path
+                        (
+                            previousSecondaryOutputTimes_.pop()
+                        )
+                    );
+                }
             }
         }
 
@@ -368,6 +414,7 @@ bool Foam::Time::writeObject
 
 bool Foam::Time::writeNow()
 {
+    primaryOutputTime_ = true;
     outputTime_ = true;
     return write();
 }
diff --git a/src/OpenFOAM/db/Time/TimeState.C b/src/OpenFOAM/db/Time/TimeState.C
index 500ca47d43ffb35c6d761886b1741dfd8dc6bf6e..f3e37401076380ceea06cc3220d24e25115f1a18 100644
--- a/src/OpenFOAM/db/Time/TimeState.C
+++ b/src/OpenFOAM/db/Time/TimeState.C
@@ -37,7 +37,9 @@ Foam::TimeState::TimeState()
     deltaT0_(0),
     deltaTchanged_(false),
     outputTimeIndex_(0),
+    primaryOutputTime_(false),
     secondaryOutputTimeIndex_(0),
+    secondaryOutputTime_(false),
     outputTime_(false)
 {}
 
diff --git a/src/engine/Make/options b/src/engine/Make/options
index 6862a106f683621de8c2e3b57f566c6e27cd1714..0929e2bc8f16444baec5e7d3b051594b0a20e031 100644
--- a/src/engine/Make/options
+++ b/src/engine/Make/options
@@ -2,12 +2,10 @@ EXE_INC = \
     -I$(LIB_SRC)/finiteVolume/lnInclude \
     -I$(LIB_SRC)/meshTools/lnInclude \
     -I$(LIB_SRC)/dynamicMesh/lnInclude \
-    -I$(LIB_SRC)/fvMotionSolver/lnInclude \
-    -I$(LIB_SRC)/sampling/lnInclude
+    -I$(LIB_SRC)/fvMotionSolver/lnInclude
 
 LIB_LIBS = \
     -lfiniteVolume \
     -lmeshTools \
     -ldynamicMesh \
-    -lfvMotionSolvers \
-    -lsampling
+    -lfvMotionSolvers
diff --git a/src/fileFormats/Make/files b/src/fileFormats/Make/files
index 7845ac93129e2050a0e8ffef4d61625bc1e96a85..37f3bc00985d82b0917bf2d4c607a57f438851b9 100644
--- a/src/fileFormats/Make/files
+++ b/src/fileFormats/Make/files
@@ -2,4 +2,17 @@ vtk/vtkUnstructuredReader.C
 nas/NASCore.C
 starcd/STARCDCore.C
 
+coordSet/coordSet.C
+
+setWriters = sampledSetWriters
+
+$(setWriters)/writers.C
+$(setWriters)/ensight/ensightSetWriterRunTime.C
+$(setWriters)/gnuplot/gnuplotSetWriterRunTime.C
+$(setWriters)/jplot/jplotSetWriterRunTime.C
+$(setWriters)/raw/rawSetWriterRunTime.C
+$(setWriters)/vtk/vtkSetWriterRunTime.C
+$(setWriters)/xmgrace/xmgraceSetWriterRunTime.C
+$(setWriters)/csv/csvSetWriterRunTime.C
+
 LIB = $(FOAM_LIBBIN)/libfileFormats
diff --git a/src/sampling/sampledSet/coordSet/coordSet.C b/src/fileFormats/coordSet/coordSet.C
similarity index 97%
rename from src/sampling/sampledSet/coordSet/coordSet.C
rename to src/fileFormats/coordSet/coordSet.C
index fed58fc86fc66536f581c28d5dd217224b36d342..d8b37c5fdd81b864fd0622c3e6f0371db329e4ab 100644
--- a/src/sampling/sampledSet/coordSet/coordSet.C
+++ b/src/fileFormats/coordSet/coordSet.C
@@ -2,7 +2,7 @@
   =========                 |
   \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
    \\    /   O peration     |
-    \\  /    A nd           | Copyright (C) 2011 OpenFOAM Foundation
+    \\  /    A nd           | Copyright (C) 2011-2012 OpenFOAM Foundation
      \\/     M anipulation  |
 -------------------------------------------------------------------------------
 License
diff --git a/src/sampling/sampledSet/coordSet/coordSet.H b/src/fileFormats/coordSet/coordSet.H
similarity index 97%
rename from src/sampling/sampledSet/coordSet/coordSet.H
rename to src/fileFormats/coordSet/coordSet.H
index 8629f78bbe46fac480ba3f7bc3c033eead6c8116..5492f37b4351f98bbb1395118d2efd836f44a11d 100644
--- a/src/sampling/sampledSet/coordSet/coordSet.H
+++ b/src/fileFormats/coordSet/coordSet.H
@@ -2,7 +2,7 @@
   =========                 |
   \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
    \\    /   O peration     |
-    \\  /    A nd           | Copyright (C) 2011 OpenFOAM Foundation
+    \\  /    A nd           | Copyright (C) 2011-2012 OpenFOAM Foundation
      \\/     M anipulation  |
 -------------------------------------------------------------------------------
 License
diff --git a/src/sampling/sampledSet/writers/csv/csvSetWriter.C b/src/fileFormats/sampledSetWriters/csv/csvSetWriter.C
similarity index 98%
rename from src/sampling/sampledSet/writers/csv/csvSetWriter.C
rename to src/fileFormats/sampledSetWriters/csv/csvSetWriter.C
index 4cbb51a597881f58f707d55c0e0863e8b0da3ddd..c1ed54b1cd84d8e05b19fdc425f04883d55f857b 100644
--- a/src/sampling/sampledSet/writers/csv/csvSetWriter.C
+++ b/src/fileFormats/sampledSetWriters/csv/csvSetWriter.C
@@ -2,7 +2,7 @@
   =========                 |
   \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
    \\    /   O peration     |
-    \\  /    A nd           | Copyright (C) 2011 OpenFOAM Foundation
+    \\  /    A nd           | Copyright (C) 2011-2012 OpenFOAM Foundation
      \\/     M anipulation  |
 -------------------------------------------------------------------------------
 License
diff --git a/src/sampling/sampledSet/writers/csv/csvSetWriter.H b/src/fileFormats/sampledSetWriters/csv/csvSetWriter.H
similarity index 97%
rename from src/sampling/sampledSet/writers/csv/csvSetWriter.H
rename to src/fileFormats/sampledSetWriters/csv/csvSetWriter.H
index 9c494320cb8abfc48fd6c07e08d371670df90458..8e4b9c7d70beb9bc5d159fcb49da7fdaffc37563 100644
--- a/src/sampling/sampledSet/writers/csv/csvSetWriter.H
+++ b/src/fileFormats/sampledSetWriters/csv/csvSetWriter.H
@@ -2,7 +2,7 @@
   =========                 |
   \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
    \\    /   O peration     |
-    \\  /    A nd           | Copyright (C) 2011 OpenFOAM Foundation
+    \\  /    A nd           | Copyright (C) 2011-2012 OpenFOAM Foundation
      \\/     M anipulation  |
 -------------------------------------------------------------------------------
 License
diff --git a/src/sampling/sampledSet/writers/csv/csvSetWriterRunTime.C b/src/fileFormats/sampledSetWriters/csv/csvSetWriterRunTime.C
similarity index 94%
rename from src/sampling/sampledSet/writers/csv/csvSetWriterRunTime.C
rename to src/fileFormats/sampledSetWriters/csv/csvSetWriterRunTime.C
index 2d326f8efaee4f14b363a265a0ef19302102d0f2..ac588e395722133f986b3c75cbacd87fe4b9eaf2 100644
--- a/src/sampling/sampledSet/writers/csv/csvSetWriterRunTime.C
+++ b/src/fileFormats/sampledSetWriters/csv/csvSetWriterRunTime.C
@@ -2,7 +2,7 @@
   =========                 |
   \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
    \\    /   O peration     |
-    \\  /    A nd           | Copyright (C) 2011 OpenFOAM Foundation
+    \\  /    A nd           | Copyright (C) 2011-2012 OpenFOAM Foundation
      \\/     M anipulation  |
 -------------------------------------------------------------------------------
 License
diff --git a/src/sampling/sampledSet/writers/ensight/ensightSetWriter.C b/src/fileFormats/sampledSetWriters/ensight/ensightSetWriter.C
similarity index 99%
rename from src/sampling/sampledSet/writers/ensight/ensightSetWriter.C
rename to src/fileFormats/sampledSetWriters/ensight/ensightSetWriter.C
index d481a4153206f9bdbcba3bb35bd360474e1d8fa7..4b874e201dfcc3e991f838780211a9551a5a2983 100644
--- a/src/sampling/sampledSet/writers/ensight/ensightSetWriter.C
+++ b/src/fileFormats/sampledSetWriters/ensight/ensightSetWriter.C
@@ -2,7 +2,7 @@
   =========                 |
   \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
    \\    /   O peration     |
-    \\  /    A nd           | Copyright (C) 2011 OpenFOAM Foundation
+    \\  /    A nd           | Copyright (C) 2011-2012 OpenFOAM Foundation
      \\/     M anipulation  |
 -------------------------------------------------------------------------------
 License
diff --git a/src/sampling/sampledSet/writers/ensight/ensightSetWriter.H b/src/fileFormats/sampledSetWriters/ensight/ensightSetWriter.H
similarity index 97%
rename from src/sampling/sampledSet/writers/ensight/ensightSetWriter.H
rename to src/fileFormats/sampledSetWriters/ensight/ensightSetWriter.H
index 5118c85faa79fbc268592aa0b37efb7c614d5608..14a735b2edc1595223369854b20204eff5895438 100644
--- a/src/sampling/sampledSet/writers/ensight/ensightSetWriter.H
+++ b/src/fileFormats/sampledSetWriters/ensight/ensightSetWriter.H
@@ -2,7 +2,7 @@
   =========                 |
   \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
    \\    /   O peration     |
-    \\  /    A nd           | Copyright (C) 2011 OpenFOAM Foundation
+    \\  /    A nd           | Copyright (C) 2011-2012 OpenFOAM Foundation
      \\/     M anipulation  |
 -------------------------------------------------------------------------------
 License
diff --git a/src/sampling/sampledSet/writers/ensight/ensightSetWriterRunTime.C b/src/fileFormats/sampledSetWriters/ensight/ensightSetWriterRunTime.C
similarity index 94%
rename from src/sampling/sampledSet/writers/ensight/ensightSetWriterRunTime.C
rename to src/fileFormats/sampledSetWriters/ensight/ensightSetWriterRunTime.C
index b987035b332e4c01e1cb1d33f391956ff6ccb392..c529cb02e48546e2b4a12166e91ced81e87086e2 100644
--- a/src/sampling/sampledSet/writers/ensight/ensightSetWriterRunTime.C
+++ b/src/fileFormats/sampledSetWriters/ensight/ensightSetWriterRunTime.C
@@ -2,7 +2,7 @@
   =========                 |
   \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
    \\    /   O peration     |
-    \\  /    A nd           | Copyright (C) 2011 OpenFOAM Foundation
+    \\  /    A nd           | Copyright (C) 2011-2012 OpenFOAM Foundation
      \\/     M anipulation  |
 -------------------------------------------------------------------------------
 License
diff --git a/src/sampling/sampledSet/writers/gnuplot/gnuplotSetWriter.C b/src/fileFormats/sampledSetWriters/gnuplot/gnuplotSetWriter.C
similarity index 97%
rename from src/sampling/sampledSet/writers/gnuplot/gnuplotSetWriter.C
rename to src/fileFormats/sampledSetWriters/gnuplot/gnuplotSetWriter.C
index f6198d3f5ab4b49d44a9090dff2f96e8c8f49922..2679e1e70231f7b826fc7dabd229660499216a06 100644
--- a/src/sampling/sampledSet/writers/gnuplot/gnuplotSetWriter.C
+++ b/src/fileFormats/sampledSetWriters/gnuplot/gnuplotSetWriter.C
@@ -2,7 +2,7 @@
   =========                 |
   \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
    \\    /   O peration     |
-    \\  /    A nd           | Copyright (C) 2011 OpenFOAM Foundation
+    \\  /    A nd           | Copyright (C) 2011-2012 OpenFOAM Foundation
      \\/     M anipulation  |
 -------------------------------------------------------------------------------
 License
@@ -24,7 +24,6 @@ License
 \*---------------------------------------------------------------------------*/
 
 #include "gnuplotSetWriter.H"
-#include "clock.H"
 #include "coordSet.H"
 #include "fileName.H"
 #include "OFstream.H"
diff --git a/src/sampling/sampledSet/writers/gnuplot/gnuplotSetWriter.H b/src/fileFormats/sampledSetWriters/gnuplot/gnuplotSetWriter.H
similarity index 97%
rename from src/sampling/sampledSet/writers/gnuplot/gnuplotSetWriter.H
rename to src/fileFormats/sampledSetWriters/gnuplot/gnuplotSetWriter.H
index 88e9414c85553374020cbda538433fa62425b839..74688771e87b568fe90efe6b8ffc98118c48d04f 100644
--- a/src/sampling/sampledSet/writers/gnuplot/gnuplotSetWriter.H
+++ b/src/fileFormats/sampledSetWriters/gnuplot/gnuplotSetWriter.H
@@ -2,7 +2,7 @@
   =========                 |
   \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
    \\    /   O peration     |
-    \\  /    A nd           | Copyright (C) 2011 OpenFOAM Foundation
+    \\  /    A nd           | Copyright (C) 2011-2012 OpenFOAM Foundation
      \\/     M anipulation  |
 -------------------------------------------------------------------------------
 License
diff --git a/src/sampling/sampledSet/writers/gnuplot/gnuplotSetWriterRunTime.C b/src/fileFormats/sampledSetWriters/gnuplot/gnuplotSetWriterRunTime.C
similarity index 94%
rename from src/sampling/sampledSet/writers/gnuplot/gnuplotSetWriterRunTime.C
rename to src/fileFormats/sampledSetWriters/gnuplot/gnuplotSetWriterRunTime.C
index 90ee2198887d5fc9e6771fdf375c654d9344632f..4e57426359ce2dedae771297aae63ba674dfa3e9 100644
--- a/src/sampling/sampledSet/writers/gnuplot/gnuplotSetWriterRunTime.C
+++ b/src/fileFormats/sampledSetWriters/gnuplot/gnuplotSetWriterRunTime.C
@@ -2,7 +2,7 @@
   =========                 |
   \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
    \\    /   O peration     |
-    \\  /    A nd           | Copyright (C) 2011 OpenFOAM Foundation
+    \\  /    A nd           | Copyright (C) 2011-2012 OpenFOAM Foundation
      \\/     M anipulation  |
 -------------------------------------------------------------------------------
 License
diff --git a/src/sampling/sampledSet/writers/jplot/jplotSetWriter.C b/src/fileFormats/sampledSetWriters/jplot/jplotSetWriter.C
similarity index 97%
rename from src/sampling/sampledSet/writers/jplot/jplotSetWriter.C
rename to src/fileFormats/sampledSetWriters/jplot/jplotSetWriter.C
index 98dc34bad93c55de2324cb5b0b1c4aab0d5d0f49..d71d860a26b74275ff2f35db5476602e44c8b9d8 100644
--- a/src/sampling/sampledSet/writers/jplot/jplotSetWriter.C
+++ b/src/fileFormats/sampledSetWriters/jplot/jplotSetWriter.C
@@ -2,7 +2,7 @@
   =========                 |
   \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
    \\    /   O peration     |
-    \\  /    A nd           | Copyright (C) 2011 OpenFOAM Foundation
+    \\  /    A nd           | Copyright (C) 2011-2012 OpenFOAM Foundation
      \\/     M anipulation  |
 -------------------------------------------------------------------------------
 License
diff --git a/src/sampling/sampledSet/writers/jplot/jplotSetWriter.H b/src/fileFormats/sampledSetWriters/jplot/jplotSetWriter.H
similarity index 97%
rename from src/sampling/sampledSet/writers/jplot/jplotSetWriter.H
rename to src/fileFormats/sampledSetWriters/jplot/jplotSetWriter.H
index bd7bc8c7834f8efd0220a35c38653e42b6c778ba..5b0945664293b4df69920a58ea913e1626e5f3f5 100644
--- a/src/sampling/sampledSet/writers/jplot/jplotSetWriter.H
+++ b/src/fileFormats/sampledSetWriters/jplot/jplotSetWriter.H
@@ -2,7 +2,7 @@
   =========                 |
   \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
    \\    /   O peration     |
-    \\  /    A nd           | Copyright (C) 2011 OpenFOAM Foundation
+    \\  /    A nd           | Copyright (C) 2011-2012 OpenFOAM Foundation
      \\/     M anipulation  |
 -------------------------------------------------------------------------------
 License
diff --git a/src/sampling/sampledSet/writers/jplot/jplotSetWriterRunTime.C b/src/fileFormats/sampledSetWriters/jplot/jplotSetWriterRunTime.C
similarity index 94%
rename from src/sampling/sampledSet/writers/jplot/jplotSetWriterRunTime.C
rename to src/fileFormats/sampledSetWriters/jplot/jplotSetWriterRunTime.C
index e0e9ac2b5267b870de516e1ee5a9e5d263887517..7e54146fe7f7f661a0ae472ca870c1c81e57eacb 100644
--- a/src/sampling/sampledSet/writers/jplot/jplotSetWriterRunTime.C
+++ b/src/fileFormats/sampledSetWriters/jplot/jplotSetWriterRunTime.C
@@ -2,7 +2,7 @@
   =========                 |
   \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
    \\    /   O peration     |
-    \\  /    A nd           | Copyright (C) 2011 OpenFOAM Foundation
+    \\  /    A nd           | Copyright (C) 2011-2012 OpenFOAM Foundation
      \\/     M anipulation  |
 -------------------------------------------------------------------------------
 License
diff --git a/src/sampling/sampledSet/writers/raw/rawSetWriter.C b/src/fileFormats/sampledSetWriters/raw/rawSetWriter.C
similarity index 97%
rename from src/sampling/sampledSet/writers/raw/rawSetWriter.C
rename to src/fileFormats/sampledSetWriters/raw/rawSetWriter.C
index e259c78eaae1794e5919e6bac66478a0ec30f7e2..403b9e71116c884ba5331acc0f9806b8b9c93340 100644
--- a/src/sampling/sampledSet/writers/raw/rawSetWriter.C
+++ b/src/fileFormats/sampledSetWriters/raw/rawSetWriter.C
@@ -2,7 +2,7 @@
   =========                 |
   \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
    \\    /   O peration     |
-    \\  /    A nd           | Copyright (C) 2011 OpenFOAM Foundation
+    \\  /    A nd           | Copyright (C) 2011-2012 OpenFOAM Foundation
      \\/     M anipulation  |
 -------------------------------------------------------------------------------
 License
diff --git a/src/sampling/sampledSet/writers/raw/rawSetWriter.H b/src/fileFormats/sampledSetWriters/raw/rawSetWriter.H
similarity index 97%
rename from src/sampling/sampledSet/writers/raw/rawSetWriter.H
rename to src/fileFormats/sampledSetWriters/raw/rawSetWriter.H
index 418549d01b6a2a42727d18314badb0d89aa83db0..89c857d779c979a76fcebf24a7198f4a844fe474 100644
--- a/src/sampling/sampledSet/writers/raw/rawSetWriter.H
+++ b/src/fileFormats/sampledSetWriters/raw/rawSetWriter.H
@@ -2,7 +2,7 @@
   =========                 |
   \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
    \\    /   O peration     |
-    \\  /    A nd           | Copyright (C) 2011 OpenFOAM Foundation
+    \\  /    A nd           | Copyright (C) 2011-2012 OpenFOAM Foundation
      \\/     M anipulation  |
 -------------------------------------------------------------------------------
 License
diff --git a/src/sampling/sampledSet/writers/raw/rawSetWriterRunTime.C b/src/fileFormats/sampledSetWriters/raw/rawSetWriterRunTime.C
similarity index 94%
rename from src/sampling/sampledSet/writers/raw/rawSetWriterRunTime.C
rename to src/fileFormats/sampledSetWriters/raw/rawSetWriterRunTime.C
index c4376c9140c1f294dc4fee32b0f75d7ee68b59f6..92a8a83354dd3d194f36d1141cea1f1f91f51f4f 100644
--- a/src/sampling/sampledSet/writers/raw/rawSetWriterRunTime.C
+++ b/src/fileFormats/sampledSetWriters/raw/rawSetWriterRunTime.C
@@ -2,7 +2,7 @@
   =========                 |
   \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
    \\    /   O peration     |
-    \\  /    A nd           | Copyright (C) 2011 OpenFOAM Foundation
+    \\  /    A nd           | Copyright (C) 2011-2012 OpenFOAM Foundation
      \\/     M anipulation  |
 -------------------------------------------------------------------------------
 License
diff --git a/src/sampling/sampledSet/writers/vtk/vtkSetWriter.C b/src/fileFormats/sampledSetWriters/vtk/vtkSetWriter.C
similarity index 98%
rename from src/sampling/sampledSet/writers/vtk/vtkSetWriter.C
rename to src/fileFormats/sampledSetWriters/vtk/vtkSetWriter.C
index b865e704d496dda72bb67ef8ec24b9771ac42fea..3ab273617500d74d57bea3b7d7f677e9ce00cc7c 100644
--- a/src/sampling/sampledSet/writers/vtk/vtkSetWriter.C
+++ b/src/fileFormats/sampledSetWriters/vtk/vtkSetWriter.C
@@ -2,7 +2,7 @@
   =========                 |
   \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
    \\    /   O peration     |
-    \\  /    A nd           | Copyright (C) 2011 OpenFOAM Foundation
+    \\  /    A nd           | Copyright (C) 2011-2012 OpenFOAM Foundation
      \\/     M anipulation  |
 -------------------------------------------------------------------------------
 License
diff --git a/src/sampling/sampledSet/writers/vtk/vtkSetWriter.H b/src/fileFormats/sampledSetWriters/vtk/vtkSetWriter.H
similarity index 97%
rename from src/sampling/sampledSet/writers/vtk/vtkSetWriter.H
rename to src/fileFormats/sampledSetWriters/vtk/vtkSetWriter.H
index 9507fd1dc78f59618c20489cfccc480fc98a4a43..21bd80ef1e7dad0c5c49c911cdf9a09152b1e684 100644
--- a/src/sampling/sampledSet/writers/vtk/vtkSetWriter.H
+++ b/src/fileFormats/sampledSetWriters/vtk/vtkSetWriter.H
@@ -2,7 +2,7 @@
   =========                 |
   \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
    \\    /   O peration     |
-    \\  /    A nd           | Copyright (C) 2011 OpenFOAM Foundation
+    \\  /    A nd           | Copyright (C) 2011-2012 OpenFOAM Foundation
      \\/     M anipulation  |
 -------------------------------------------------------------------------------
 License
diff --git a/src/sampling/sampledSet/writers/vtk/vtkSetWriterRunTime.C b/src/fileFormats/sampledSetWriters/vtk/vtkSetWriterRunTime.C
similarity index 94%
rename from src/sampling/sampledSet/writers/vtk/vtkSetWriterRunTime.C
rename to src/fileFormats/sampledSetWriters/vtk/vtkSetWriterRunTime.C
index 3c30764d86abf2bffd75745f2845ccc13cb1f533..e9320e5b5589bbeaee00f80c7f0b110214ee83cc 100644
--- a/src/sampling/sampledSet/writers/vtk/vtkSetWriterRunTime.C
+++ b/src/fileFormats/sampledSetWriters/vtk/vtkSetWriterRunTime.C
@@ -2,7 +2,7 @@
   =========                 |
   \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
    \\    /   O peration     |
-    \\  /    A nd           | Copyright (C) 2011 OpenFOAM Foundation
+    \\  /    A nd           | Copyright (C) 2011-2012 OpenFOAM Foundation
      \\/     M anipulation  |
 -------------------------------------------------------------------------------
 License
diff --git a/src/sampling/sampledSet/writers/writer.C b/src/fileFormats/sampledSetWriters/writer.C
similarity index 99%
rename from src/sampling/sampledSet/writers/writer.C
rename to src/fileFormats/sampledSetWriters/writer.C
index 69dbdec6fe7a14c5b7ec1c5834682b8f6396a316..e031615ff69acc407599b1917d1964cba6cd472a 100644
--- a/src/sampling/sampledSet/writers/writer.C
+++ b/src/fileFormats/sampledSetWriters/writer.C
@@ -166,7 +166,6 @@ void Foam::writer<Type>::write
     {
         valueSetPtrs[i] = &valueSets[i];
     }
-    
     write(points, valueSetNames, valueSetPtrs, os);
 }
 
diff --git a/src/sampling/sampledSet/writers/writer.H b/src/fileFormats/sampledSetWriters/writer.H
similarity index 100%
rename from src/sampling/sampledSet/writers/writer.H
rename to src/fileFormats/sampledSetWriters/writer.H
diff --git a/src/sampling/sampledSet/writers/writers.C b/src/fileFormats/sampledSetWriters/writers.C
similarity index 96%
rename from src/sampling/sampledSet/writers/writers.C
rename to src/fileFormats/sampledSetWriters/writers.C
index 2815bcda039f04011815a281b1d5561d244b3cd1..4bcc1b39b28b1911509a8d76a90caad28bb200c2 100644
--- a/src/sampling/sampledSet/writers/writers.C
+++ b/src/fileFormats/sampledSetWriters/writers.C
@@ -2,7 +2,7 @@
   =========                 |
   \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
    \\    /   O peration     |
-    \\  /    A nd           | Copyright (C) 2011 OpenFOAM Foundation
+    \\  /    A nd           | Copyright (C) 2011-2012 OpenFOAM Foundation
      \\/     M anipulation  |
 -------------------------------------------------------------------------------
 License
diff --git a/src/sampling/sampledSet/writers/writers.H b/src/fileFormats/sampledSetWriters/writers.H
similarity index 97%
rename from src/sampling/sampledSet/writers/writers.H
rename to src/fileFormats/sampledSetWriters/writers.H
index 3adaab13fa028985d3a0552121aa6aa064a62df1..601e7bcd16108f6be6d2e74d9fb524dee6ea62b2 100644
--- a/src/sampling/sampledSet/writers/writers.H
+++ b/src/fileFormats/sampledSetWriters/writers.H
@@ -2,7 +2,7 @@
   =========                 |
   \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
    \\    /   O peration     |
-    \\  /    A nd           | Copyright (C) 2011 OpenFOAM Foundation
+    \\  /    A nd           | Copyright (C) 2011-2012 OpenFOAM Foundation
      \\/     M anipulation  |
 -------------------------------------------------------------------------------
 License
diff --git a/src/sampling/sampledSet/writers/xmgrace/xmgraceSetWriter.C b/src/fileFormats/sampledSetWriters/xmgrace/xmgraceSetWriter.C
similarity index 98%
rename from src/sampling/sampledSet/writers/xmgrace/xmgraceSetWriter.C
rename to src/fileFormats/sampledSetWriters/xmgrace/xmgraceSetWriter.C
index 9cc44a10c38e15963fc5979711b33f0ab85bc80e..3825868196d4c6c7b256c541c3b5649b8daf5d56 100644
--- a/src/sampling/sampledSet/writers/xmgrace/xmgraceSetWriter.C
+++ b/src/fileFormats/sampledSetWriters/xmgrace/xmgraceSetWriter.C
@@ -2,7 +2,7 @@
   =========                 |
   \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
    \\    /   O peration     |
-    \\  /    A nd           | Copyright (C) 2011 OpenFOAM Foundation
+    \\  /    A nd           | Copyright (C) 2011-2012 OpenFOAM Foundation
      \\/     M anipulation  |
 -------------------------------------------------------------------------------
 License
diff --git a/src/sampling/sampledSet/writers/xmgrace/xmgraceSetWriter.H b/src/fileFormats/sampledSetWriters/xmgrace/xmgraceSetWriter.H
similarity index 97%
rename from src/sampling/sampledSet/writers/xmgrace/xmgraceSetWriter.H
rename to src/fileFormats/sampledSetWriters/xmgrace/xmgraceSetWriter.H
index 8e8dc67ead500e2859613b6cc9c57b1f0f96bfcc..47c36289366591a65af2a14bc0da1247c89a1e6c 100644
--- a/src/sampling/sampledSet/writers/xmgrace/xmgraceSetWriter.H
+++ b/src/fileFormats/sampledSetWriters/xmgrace/xmgraceSetWriter.H
@@ -2,7 +2,7 @@
   =========                 |
   \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
    \\    /   O peration     |
-    \\  /    A nd           | Copyright (C) 2011 OpenFOAM Foundation
+    \\  /    A nd           | Copyright (C) 2011-2012 OpenFOAM Foundation
      \\/     M anipulation  |
 -------------------------------------------------------------------------------
 License
diff --git a/src/sampling/sampledSet/writers/xmgrace/xmgraceSetWriterRunTime.C b/src/fileFormats/sampledSetWriters/xmgrace/xmgraceSetWriterRunTime.C
similarity index 94%
rename from src/sampling/sampledSet/writers/xmgrace/xmgraceSetWriterRunTime.C
rename to src/fileFormats/sampledSetWriters/xmgrace/xmgraceSetWriterRunTime.C
index 8e7ab61c8e2bc2b0ad489c22050c107a3c93b77a..583855fc8331b54844b07bf1bb069106e3ee11dd 100644
--- a/src/sampling/sampledSet/writers/xmgrace/xmgraceSetWriterRunTime.C
+++ b/src/fileFormats/sampledSetWriters/xmgrace/xmgraceSetWriterRunTime.C
@@ -2,7 +2,7 @@
   =========                 |
   \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
    \\    /   O peration     |
-    \\  /    A nd           | Copyright (C) 2011 OpenFOAM Foundation
+    \\  /    A nd           | Copyright (C) 2011-2012 OpenFOAM Foundation
      \\/     M anipulation  |
 -------------------------------------------------------------------------------
 License
diff --git a/src/fvMotionSolver/Make/options b/src/fvMotionSolver/Make/options
index fa13513b50fbf34e09087c06eb56bc413d357a5e..29e4469610118cb4f0468cba7f80f5aacbf7a1fd 100644
--- a/src/fvMotionSolver/Make/options
+++ b/src/fvMotionSolver/Make/options
@@ -3,7 +3,7 @@ EXE_INC = \
     -I$(LIB_SRC)/meshTools/lnInclude \
     -I$(LIB_SRC)/dynamicMesh/lnInclude \
     -I$(LIB_SRC)/finiteVolume/lnInclude \
-    -I$(LIB_SRC)/sampling/lnInclude \
+    -I$(LIB_SRC)/fileFormats/lnInclude \
     -I$(LIB_SRC)/postProcessing/functionObjects/forces/lnInclude \
 
 LIB_LIBS = \
@@ -11,4 +11,5 @@ LIB_LIBS = \
     -lmeshTools \
     -ldynamicMesh \
     -lfiniteVolume \
+    -lfileFormats
     /*-lforces include in controlDict if needed */
diff --git a/src/lagrangian/coalCombustion/Make/options b/src/lagrangian/coalCombustion/Make/options
index 34a2babd735d8e8a6b2e69c447755c3660058595..0d7eb0e13ba648b92847e780c1bed3fa70b8e7c2 100644
--- a/src/lagrangian/coalCombustion/Make/options
+++ b/src/lagrangian/coalCombustion/Make/options
@@ -17,8 +17,7 @@ EXE_INC = \
     -I$(LIB_SRC)/transportModels \
     -I$(LIB_SRC)/regionModels/regionModel/lnInclude \
     -I$(LIB_SRC)/regionModels/surfaceFilmModels/lnInclude \
-    -I$(LIB_SRC)/dynamicFvMesh/lnInclude \
-    -I$(LIB_SRC)/sampling/lnInclude
+    -I$(LIB_SRC)/dynamicFvMesh/lnInclude
 
 LIB_LIBS = \
     -lfiniteVolume \
@@ -42,5 +41,4 @@ LIB_LIBS = \
     -lincompressibleTransportModels \
     -lregionModels \
     -lsurfaceFilmModels \
-    -ldynamicFvMesh \
-    -lsampling
+    -ldynamicFvMesh
diff --git a/src/mesh/autoMesh/Make/options b/src/mesh/autoMesh/Make/options
index 0ee4f07bb039ccdf6b15f6182b77b60c47d89ec0..d37a26a9dd460742d9203623e4ddf6f69a4c99de 100644
--- a/src/mesh/autoMesh/Make/options
+++ b/src/mesh/autoMesh/Make/options
@@ -4,7 +4,7 @@ EXE_INC = \
     -I$(LIB_SRC)/finiteVolume/lnInclude \
     -I$(LIB_SRC)/lagrangian/basic/lnInclude \
     -I$(LIB_SRC)/meshTools/lnInclude \
-    -I$(LIB_SRC)/sampling/lnInclude \
+    -I$(LIB_SRC)/fileFormats/lnInclude \
     -I$(LIB_SRC)/edgeMesh/lnInclude \
     -I$(LIB_SRC)/surfMesh/lnInclude \
     -I$(LIB_SRC)/triSurface/lnInclude
@@ -14,6 +14,7 @@ LIB_LIBS = \
     -lfiniteVolume \
     -llagrangian \
     -lmeshTools \
+    -lfileFormats \
     -ledgeMesh \
     -lsurfMesh \
     -ltriSurface \
diff --git a/src/mesh/autoMesh/autoHexMesh/meshRefinement/meshRefinement.C b/src/mesh/autoMesh/autoHexMesh/meshRefinement/meshRefinement.C
index 2890577c24b01fc80a96fc092a785248966a5dba..26a40327d6f610118c88c560b43419e7b8c86587 100644
--- a/src/mesh/autoMesh/autoHexMesh/meshRefinement/meshRefinement.C
+++ b/src/mesh/autoMesh/autoHexMesh/meshRefinement/meshRefinement.C
@@ -2295,13 +2295,6 @@ void Foam::meshRefinement::dumpIntersections(const fileName& prefix) const
         }
     }
 
-    // Convert to vtk format
-    string cmd
-    (
-        "objToVTK " + prefix + "_edges.obj " + prefix + "_edges.vtk > /dev/null"
-    );
-    system(cmd.c_str());
-
     Pout<< endl;
 }
 
diff --git a/src/meshTools/Make/options b/src/meshTools/Make/options
index ac717c75165175856a5b5d27b056357166ed0956..1b22dab2a0fd8549e981e74b454bd985bdb45c3a 100644
--- a/src/meshTools/Make/options
+++ b/src/meshTools/Make/options
@@ -1,6 +1,7 @@
 EXE_INC = \
     -I$(LIB_SRC)/triSurface/lnInclude \
-    -I$(LIB_SRC)/sampling/lnInclude
+    -I$(LIB_SRC)/fileFormats/lnInclude
 
 LIB_LIBS = \
-    -ltriSurface
+    -ltriSurface \
+    -lfileFormats
diff --git a/src/postProcessing/functionObjects/IO/Make/options b/src/postProcessing/functionObjects/IO/Make/options
index 5166bcc9e32f547f48a5f87c9c60d7210409967f..a3ae8da833177387e9eecf75b5e2675fc7b481f5 100644
--- a/src/postProcessing/functionObjects/IO/Make/options
+++ b/src/postProcessing/functionObjects/IO/Make/options
@@ -1,9 +1,7 @@
 EXE_INC = \
     -I$(LIB_SRC)/finiteVolume/lnInclude \
-    -I$(LIB_SRC)/meshTools/lnInclude \
-    -I$(LIB_SRC)/sampling/lnInclude
+    -I$(LIB_SRC)/meshTools/lnInclude
 
 LIB_LIBS = \
     -lfiniteVolume \
-    -lmeshTools \
-    -lsampling
+    -lmeshTools
diff --git a/src/postProcessing/functionObjects/field/Make/options b/src/postProcessing/functionObjects/field/Make/options
index d7c5f944c60caad1eb365309b14a6bb6e6913c9f..e95ea37c7876c2daeafaf58798c39db0e616abc7 100644
--- a/src/postProcessing/functionObjects/field/Make/options
+++ b/src/postProcessing/functionObjects/field/Make/options
@@ -2,6 +2,7 @@ EXE_INC = \
     -I$(LIB_SRC)/finiteVolume/lnInclude \
     -I$(LIB_SRC)/meshTools/lnInclude \
     -I$(LIB_SRC)/lagrangian/basic/lnInclude \
+    -I$(LIB_SRC)/fileFormats/lnInclude \
     -I$(LIB_SRC)/sampling/lnInclude \
     -I$(LIB_SRC)/transportModels \
     -I$(LIB_SRC)/turbulenceModels \
@@ -11,6 +12,7 @@ LIB_LIBS = \
     -lfiniteVolume \
     -lmeshTools \
     -llagrangian \
+    -lfileFormats \
     -lsampling \
     -lincompressibleTransportModels \
     -lcompressibleTurbulenceModel \
diff --git a/src/postProcessing/functionObjects/forces/Make/options b/src/postProcessing/functionObjects/forces/Make/options
index afc10fb1aad15a165291f66c0861d7362061da13..5952c6b6cb5f66e783d7dddeaccce7bdf5f89f25 100644
--- a/src/postProcessing/functionObjects/forces/Make/options
+++ b/src/postProcessing/functionObjects/forces/Make/options
@@ -1,7 +1,7 @@
 EXE_INC = \
     -I$(LIB_SRC)/finiteVolume/lnInclude \
     -I$(LIB_SRC)/meshTools/lnInclude \
-    -I$(LIB_SRC)/sampling/lnInclude \
+    -I$(LIB_SRC)/fileFormats/lnInclude \
     -I$(LIB_SRC)/transportModels \
     -I$(LIB_SRC)/turbulenceModels \
     -I$(LIB_SRC)/turbulenceModels/LES/LESdeltas/lnInclude \
@@ -17,4 +17,4 @@ LIB_LIBS = \
     -lcompressibleLESModels \
     -lfiniteVolume \
     -lmeshTools \
-    -lsampling
+    -lfileFormats
diff --git a/src/postProcessing/functionObjects/jobControl/Make/options b/src/postProcessing/functionObjects/jobControl/Make/options
index 5166bcc9e32f547f48a5f87c9c60d7210409967f..e69de29bb2d1d6434b8b29ae775ad8c2e48c5391 100644
--- a/src/postProcessing/functionObjects/jobControl/Make/options
+++ b/src/postProcessing/functionObjects/jobControl/Make/options
@@ -1,9 +0,0 @@
-EXE_INC = \
-    -I$(LIB_SRC)/finiteVolume/lnInclude \
-    -I$(LIB_SRC)/meshTools/lnInclude \
-    -I$(LIB_SRC)/sampling/lnInclude
-
-LIB_LIBS = \
-    -lfiniteVolume \
-    -lmeshTools \
-    -lsampling
diff --git a/src/postProcessing/functionObjects/systemCall/Make/options b/src/postProcessing/functionObjects/systemCall/Make/options
index 5166bcc9e32f547f48a5f87c9c60d7210409967f..e69de29bb2d1d6434b8b29ae775ad8c2e48c5391 100644
--- a/src/postProcessing/functionObjects/systemCall/Make/options
+++ b/src/postProcessing/functionObjects/systemCall/Make/options
@@ -1,9 +0,0 @@
-EXE_INC = \
-    -I$(LIB_SRC)/finiteVolume/lnInclude \
-    -I$(LIB_SRC)/meshTools/lnInclude \
-    -I$(LIB_SRC)/sampling/lnInclude
-
-LIB_LIBS = \
-    -lfiniteVolume \
-    -lmeshTools \
-    -lsampling
diff --git a/src/randomProcesses/Make/options b/src/randomProcesses/Make/options
index 61fc018ad930d8d5dda59891e9e59e52ff1ecba6..71b7873964d544eddf96d22aa40f4c3372c23c9c 100644
--- a/src/randomProcesses/Make/options
+++ b/src/randomProcesses/Make/options
@@ -1,7 +1,5 @@
 EXE_INC = \
-    -I$(LIB_SRC)/finiteVolume/lnInclude \
-    -I$(LIB_SRC)/sampling/lnInclude
+    -I$(LIB_SRC)/finiteVolume/lnInclude
 
 LIB_LIBS = \
-    -lfiniteVolume \
-    -lsampling
+    -lfiniteVolume
diff --git a/src/regionModels/regionCoupling/Make/options b/src/regionModels/regionCoupling/Make/options
index 4eaef77e23fdb8a64cf01f11691b13a6f70283ad..28569ccda68e500c6b26cfab904e9507bd6fa120 100644
--- a/src/regionModels/regionCoupling/Make/options
+++ b/src/regionModels/regionCoupling/Make/options
@@ -1,6 +1,5 @@
 EXE_INC = \
     -I$(LIB_SRC)/finiteVolume/lnInclude \
-    -I$(LIB_SRC)/sampling/lnInclude \
     -I$(LIB_SRC)/AMIInterpolation/lnInclude \
     -I$(LIB_SRC)/meshTools/lnInclude \
     -I$(LIB_SRC)/thermophysicalModels/chemistryModel/lnInclude \
diff --git a/src/regionModels/thermoBaffleModels/Make/options b/src/regionModels/thermoBaffleModels/Make/options
index 2c0e2cf57ca23b57686ac288837710aa4ba0174d..21a54595be530da1a87d94e9e1aacdedb522cdea 100644
--- a/src/regionModels/thermoBaffleModels/Make/options
+++ b/src/regionModels/thermoBaffleModels/Make/options
@@ -3,7 +3,6 @@ EXE_INC = \
     -I$(LIB_SRC)/thermophysicalModels/solidThermo/lnInclude \
     -I$(LIB_SRC)/finiteVolume/lnInclude \
     -I$(LIB_SRC)/meshTools/lnInclude \
-    -I$(LIB_SRC)/sampling/lnInclude \
     -I$(LIB_SRC)/AMIInterpolation/lnInclude \
     -I$(LIB_SRC)/thermophysicalModels/basic/lnInclude \
     -I$(LIB_SRC)/thermophysicalModels/specie/lnInclude \
diff --git a/src/sampling/Make/files b/src/sampling/Make/files
index 8c5227dbf206a2ec9cf3560c42e10d82435ae6ca..ef0415f0f24848e1ea802c699731ac6587d69a29 100644
--- a/src/sampling/Make/files
+++ b/src/sampling/Make/files
@@ -5,7 +5,6 @@ probes/probesFunctionObject/probesFunctionObject.C
 
 sampledSet/circle/circleSet.C
 sampledSet/cloud/cloudSet.C
-sampledSet/coordSet/coordSet.C
 sampledSet/patchCloud/patchCloudSet.C
 sampledSet/polyLine/polyLineSet.C
 sampledSet/face/faceOnlySet.C
@@ -20,17 +19,6 @@ sampledSet/triSurfaceMeshPointSet/triSurfaceMeshPointSet.C
 sampledSet/uniform/uniformSet.C
 sampledSet/array/arraySet.C
 
-setWriters = sampledSet/writers
-
-$(setWriters)/writers.C
-$(setWriters)/ensight/ensightSetWriterRunTime.C
-$(setWriters)/gnuplot/gnuplotSetWriterRunTime.C
-$(setWriters)/jplot/jplotSetWriterRunTime.C
-$(setWriters)/raw/rawSetWriterRunTime.C
-$(setWriters)/vtk/vtkSetWriterRunTime.C
-$(setWriters)/xmgrace/xmgraceSetWriterRunTime.C
-$(setWriters)/csv/csvSetWriterRunTime.C
-
 cuttingPlane/cuttingPlane.C
 
 sampledSurface/sampledPatch/sampledPatch.C
diff --git a/src/sampling/Make/options b/src/sampling/Make/options
index 3fbc509d541cb70355abee9f03412bea6c2d2528..23e6bc81a7e708d69b5fd14d27073827646e14ef 100644
--- a/src/sampling/Make/options
+++ b/src/sampling/Make/options
@@ -2,6 +2,7 @@ EXE_INC = \
     -I$(LIB_SRC)/finiteVolume/lnInclude \
     -I$(LIB_SRC)/meshTools/lnInclude \
     -I$(LIB_SRC)/surfMesh/lnInclude \
+    -I$(LIB_SRC)/fileFormats/lnInclude \
     -I$(LIB_SRC)/triSurface/lnInclude \
     -I$(LIB_SRC)/conversion/lnInclude \
     -I$(LIB_SRC)/lagrangian/basic/lnInclude
@@ -10,6 +11,7 @@ LIB_LIBS = \
     -lfiniteVolume \
     -lmeshTools \
     -lsurfMesh \
+    -lfileFormats \
     -ltriSurface \
     -llagrangian \
     -lconversion
diff --git a/src/sampling/sampledSurface/writers/nastran/nastranSurfaceWriterTemplates.C b/src/sampling/sampledSurface/writers/nastran/nastranSurfaceWriterTemplates.C
index e01429fc88cbea5018d7f5bcb128927df49341ea..e43dc5757fe2762dce15951679509b37e456ab48 100644
--- a/src/sampling/sampledSurface/writers/nastran/nastranSurfaceWriterTemplates.C
+++ b/src/sampling/sampledSurface/writers/nastran/nastranSurfaceWriterTemplates.C
@@ -25,6 +25,7 @@ License
 
 #include "OFstream.H"
 #include "IOmanip.H"
+#include "OSspecific.H"
 
 // * * * * * * * * * * * * * Private Member Functions  * * * * * * * * * * * //
 
diff --git a/src/sampling/sampledSurface/writers/surfaceWriter.H b/src/sampling/sampledSurface/writers/surfaceWriter.H
index dd54a756c69f1b927d20882f0259ce093200ebe6..84ca3cdf5d57ba6e38c2326eed2bef5aad6f1ec4 100644
--- a/src/sampling/sampledSurface/writers/surfaceWriter.H
+++ b/src/sampling/sampledSurface/writers/surfaceWriter.H
@@ -35,7 +35,6 @@ SourceFiles
 #ifndef surfaceWriter_H
 #define surfaceWriter_H
 
-#include "volFields.H"
 #include "typeInfo.H"
 #include "autoPtr.H"
 #include "pointField.H"
diff --git a/src/OpenFOAM/db/Time/TimeState.H b/src/OpenFOAM/db/Time/TimeState.H
index d721529480ea79ce2de2b9f4cca74875ea11502b..b055d439f0f8389c8f4183d84e7259ef4040f2f1 100644
--- a/src/OpenFOAM/db/Time/TimeState.H
+++ b/src/OpenFOAM/db/Time/TimeState.H
@@ -61,8 +61,14 @@ protected:
         bool deltaTchanged_;
 
         label outputTimeIndex_;
+        //- Is outputTime because of primary?
+        bool primaryOutputTime_;
+
         label secondaryOutputTimeIndex_;
-        bool  outputTime_;
+        //- Is outputTime because of secondary?
+        bool secondaryOutputTime_;
+
+        bool outputTime_;
 
 public:
 
@@ -112,7 +118,7 @@ public:
 
         // Check
 
             //- Return true if this is an output time
             bool outputTime() const;
 };
 
@@ -112,7 +118,7 @@ public:
         // Check
 
-            //- Return true if this is an output time
+            //- Return true if this is an output time (primary or secondary)
             bool outputTime() const;
 };